==> apache-druid-31.0.2-src.tar.gz: apache-druid-31.0.2-src/server/src/test/java/org/apache/druid/messages/MessageBatchTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.messages;

import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.google.common.collect.ImmutableList;
import nl.jqno.equalsverifier.EqualsVerifier;
import org.apache.druid.segment.TestHelper;
import org.junit.Assert;
import org.junit.Test;

import java.io.IOException;

public class MessageBatchTest
{
  @Test
  public void test_serde() throws IOException
  {
    final ObjectMapper objectMapper = TestHelper.JSON_MAPPER;
    final MessageBatch<String> batch = new MessageBatch<>(ImmutableList.of("foo", "bar"), 123L, 456L);
    final MessageBatch<String> batch2 =
        objectMapper.readValue(objectMapper.writeValueAsBytes(batch), new TypeReference<MessageBatch<String>>() {});
    Assert.assertEquals(batch, batch2);
  }

  @Test
  public void test_equals()
  {
    EqualsVerifier.forClass(MessageBatch.class)
                  .usingGetClass()
                  .verify();
  }
}

==> apache-druid-33.0.0-src.tar.gz: apache-druid-33.0.0-src/server/src/test/java/org/apache/druid/messages/MessageBatchTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.messages;

import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.google.common.collect.ImmutableList;
import nl.jqno.equalsverifier.EqualsVerifier;
import org.apache.druid.segment.TestHelper;
import org.junit.Assert;
import org.junit.Test;

import java.io.IOException;

public class MessageBatchTest
{
  @Test
  public void test_serde() throws IOException
  {
    final ObjectMapper objectMapper = TestHelper.JSON_MAPPER;
    final MessageBatch<String> batch = new MessageBatch<>(ImmutableList.of("foo", "bar"), 123L, 456L);
    final MessageBatch<String> batch2 =
        objectMapper.readValue(objectMapper.writeValueAsBytes(batch), new TypeReference<>() {});
    Assert.assertEquals(batch, batch2);
  }

  @Test
  public void test_equals()
  {
    EqualsVerifier.forClass(MessageBatch.class)
                  .usingGetClass()
                  .verify();
  }
}
